# Installation

Before you begin, ensure that you have the following installed:

- [Python](https://www.python.org/) version 3.11 or higher
- [Pip](https://pip.pypa.io/)

Additional dependencies will be installed using the `pip` command below.
Familiarity with [Pip](https://pip.pypa.io/) is assumed.
We recommend performing the installation within a [Python virtual environment](https://docs.python.org/3/library/venv.html).

To install STACIE, use the following shell command:

```bash
pip install stacie
```
